==> MuMIn_1.43.10.tar.gz: MuMIn/R/umf_specs.R <==
umf_specs <-
list(unmarkedFitColExt = list(structure(c("psiformula", "psi", 
"psi", "psiformula", "gammaformula", "col", "col", "gamformula", 
"epsilonformula", "ext", "ext", "epsformula", "pformula", "p", 
"det", "detformula"), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName", "formulaItemName"
), c("psi", "col", "ext", "p")))), unmarkedFitDS = list(structure(c("formula", 
"p", "det", "formula", "lam", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "lam"))), structure(c("formula", NA, NA, "formula", 
"lam", "state"), .Dim = 3:2, .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName"), c("p", "lam"))), 
    structure(c("formula", "lam", "state", "formula", "p", "det", 
    NA, "p", "scale"), .Dim = c(3L, 3L), .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName"), c("lam", "p", 
    "scale"))), structure(c("formula", "lam", "state", "formula", 
    "p", "det", NA, "p", "scale"), .Dim = c(3L, 3L), .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("lam", "p", "scale")))), unmarkedFitGDS = list(structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula", NA, "scale", 
"scale", NA), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName", "formulaItemName"
), c("lambda", "phi", "p", "scale"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", NA, NA, "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula", NA, "scale", 
"scale", NA, NA, "alpha", "alpha", NA), .Dim = 4:5, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p", "scale", "alpha"
    )))), unmarkedFitGMM = list(structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p")))), unmarkedFitGPC = list(
    structure(c("lambdaformula", "lambda", "lambda", "lambdaformula", 
    "phiformula", "phi", "phi", "phiformula", "pformula", "p", 
    "det", "pformula"), .Dim = 4:3, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lambda", "phi", "p")))), unmarkedFitMPois = list(structure(c("formula", 
"p", "det", "formula", "lambda", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "lambda")))), unmarkedFitOccu = list(structure(c("formula", 
"p", "det", "formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "psi")))), unmarkedFitOccuFP = list(structure(c("Bformula", 
NA, NA, "Bformula", "FPformula", "fp", "fp", "FPformula", "detformula", 
"p", "det", "detformula", "stateformula", "psi", "state", "stateformula"
), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", "estimate:short.name", 
"estimate:itemName", "formulaItemName"), c("b", "fp", "p", "psi"
)))), unmarkedFitOccuPEN = list(structure(c("formula", "p", "det", 
"formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName"), c("p", "psi")))), 
    unmarkedFitOccuPEN_CV = list(structure(c("formula", "p", 
    "det", "formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("p", "psi")))), unmarkedFitOccuRN = list(structure(c("formula", 
    "p", "det", "formula", "lam", "state"), .Dim = 3:2, .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("p", "lam")))), unmarkedFitPCO = list(structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "omegaformula", "omega", "omega", 
    "omegaformula", "pformula", "p", "det", "pformula", "iotaformula", 
    NA, NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "omega", "p", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "omegaformula", "omega", 
    "omega", "omegaformula", "pformula", "p", "det", "pformula", 
    "gammaformula", NA, NA, "gammaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "omega", "p", "gamma", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "pformula", "p", "det", "pformula", 
    "omegaformula", NA, NA, "omegaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "p", "omega", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "omegaformula", "om", "omega", "omegaformula", 
    "pformula", "p", "det", "pformula", "iotaformula", NA, NA, 
    "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "om", "p", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "pformula", "p", "det", "pformula", 
    "omegaformula", NA, NA, "omegaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "p", "omega", "iota")))), unmarkedFitPCount = list(
        structure(c("formula", "p", "det", "formula", "lam", 
        "state", NA, "alpha", "alpha"), .Dim = c(3L, 3L), .Dimnames = list(
            c("formula.arg", "estimate:short.name", "estimate:itemName"
            ), c("p", "lam", "alpha"))), structure(c("formula", 
        "p", "det", "formula", "lam", "state"), .Dim = 3:2, .Dimnames = list(
            c("formula.arg", "estimate:short.name", "estimate:itemName"
            ), c("p", "lam")))))

==> MuMIn_1.46.0.tar.gz: MuMIn/R/umf_specs.R <==
umf_specs <-
list(unmarkedFitColExt = list(structure(c("psiformula", "psi", 
"psi", "psiformula", "gammaformula", "col", "col", "gamformula", 
"epsilonformula", "ext", "ext", "epsformula", "pformula", "p", 
"det", "detformula"), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName", "formulaItemName"
), c("psi", "col", "ext", "p")))), unmarkedFitDS = list(structure(c("formula", 
"p", "det", "formula", "lam", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "lam"))), structure(c("formula", NA, NA, "formula", 
"lam", "state"), .Dim = 3:2, .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName"), c("p", "lam"))), 
    structure(c("formula", "lam", "state", "formula", "p", "det", 
    NA, "p", "scale"), .Dim = c(3L, 3L), .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName"), c("lam", "p", 
    "scale"))), structure(c("formula", "lam", "state", "formula", 
    "p", "det", NA, "p", "scale"), .Dim = c(3L, 3L), .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("lam", "p", "scale")))), unmarkedFitGDS = list(structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula", NA, "scale", 
"scale", NA), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName", "formulaItemName"
), c("lambda", "phi", "p", "scale"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", NA, NA, "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p"))), structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula", NA, "scale", 
"scale", NA, NA, "alpha", "alpha", NA), .Dim = 4:5, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p", "scale", "alpha"
    )))), unmarkedFitGMM = list(structure(c("lambdaformula", 
"lambda", "lambda", "lambdaformula", "phiformula", "phi", "phi", 
"phiformula", "pformula", "p", "det", "pformula"), .Dim = 4:3, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName", 
    "formulaItemName"), c("lambda", "phi", "p")))), unmarkedFitGPC = list(
    structure(c("lambdaformula", "lambda", "lambda", "lambdaformula", 
    "phiformula", "phi", "phi", "phiformula", "pformula", "p", 
    "det", "pformula"), .Dim = 4:3, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lambda", "phi", "p")))), unmarkedFitMPois = list(structure(c("formula", 
"p", "det", "formula", "lambda", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "lambda")))), unmarkedFitOccu = list(structure(c("formula", 
"p", "det", "formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(
    c("formula.arg", "estimate:short.name", "estimate:itemName"
    ), c("p", "psi")))), unmarkedFitOccuFP = list(structure(c("Bformula", 
NA, NA, "Bformula", "FPformula", "fp", "fp", "FPformula", "detformula", 
"p", "det", "detformula", "stateformula", "psi", "state", "stateformula"
), .Dim = c(4L, 4L), .Dimnames = list(c("formula.arg", "estimate:short.name", 
"estimate:itemName", "formulaItemName"), c("b", "fp", "p", "psi"
)))), unmarkedFitOccuPEN = list(structure(c("formula", "p", "det", 
"formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName"), c("p", "psi")))), 
    unmarkedFitOccuPEN_CV = list(structure(c("formula", "p", 
    "det", "formula", "psi", "state"), .Dim = 3:2, .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("p", "psi")))), unmarkedFitOccuRN = list(structure(c("formula", 
    "p", "det", "formula", "lam", "state"), .Dim = 3:2, .Dimnames = list(
        c("formula.arg", "estimate:short.name", "estimate:itemName"
        ), c("p", "lam")))), unmarkedFitPCO = list(structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "omegaformula", "omega", "omega", 
    "omegaformula", "pformula", "p", "det", "pformula", "iotaformula", 
    NA, NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "omega", "p", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "omegaformula", "omega", 
    "omega", "omegaformula", "pformula", "p", "det", "pformula", 
    "gammaformula", NA, NA, "gammaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "omega", "p", "gamma", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "pformula", "p", "det", "pformula", 
    "omegaformula", NA, NA, "omegaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "p", "omega", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "omegaformula", "om", "omega", "omegaformula", 
    "pformula", "p", "det", "pformula", "iotaformula", NA, NA, 
    "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "om", "p", "iota"))), structure(c("lambdaformula", 
    "lam", "lambda", "lambdaformula", "gammaformula", "gam", 
    "gamma", "gammaformula", "pformula", "p", "det", "pformula", 
    "omegaformula", NA, NA, "omegaformula", "iotaformula", NA, 
    NA, "iotaformula"), .Dim = 4:5, .Dimnames = list(c("formula.arg", 
    "estimate:short.name", "estimate:itemName", "formulaItemName"
    ), c("lam", "gam", "p", "omega", "iota")))), unmarkedFitPCount = 
    list(structure(c("formula", "p", "det", "formula", "lam", "state", 
NA, "alpha", "alpha"), .Dim = c(3L, 3L), .Dimnames = list(c("formula.arg", 
"estimate:short.name", "estimate:itemName"), c("p", "lam", "alpha"
))), structure(c("formula", "p", "det", "formula", "lam", "state"
), .Dim = 3:2, .Dimnames = list(c("formula.arg", "estimate:short.name", 
"estimate:itemName"), c("p", "lam"))), structure(c("formula", 
"p", "det", "formula", "lam", "state", NA, "psi", "psi"), .Dim = c(3L, 
3L), .Dimnames = list(c("formula.arg", "estimate:short.name", 
"estimate:itemName"), c("p", "lam", "psi")))))
